/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  06/22/00:  Release version 0.3.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CAnimatedCanvas.
 *
 * @version   0.3  06/22/00
 * @author    Ying Chen, Chip Watson
 * @since     adm0.3
 *
 */

public class CAnimatedCanvasBeanInfo extends SimpleBeanInfo {

    private final static Class BEAN_CLASS = CAnimatedCanvas.class;

    public BeanInfo[] getAdditionalBeanInfo() {
	try {
	    java.util.Vector v = new java.util.Vector();
	    BeanInfo[] rv;
	    BeanInfo b;
	    Class c = BEAN_CLASS.getSuperclass();
	    
	    while (c.isAssignableFrom(Object.class) != true) {
		b = Introspector.getBeanInfo(c);
		v.addElement(b);
		c = c.getSuperclass();
	    }
	    rv = new BeanInfo[v.size()];
	    v.copyInto(rv);
	    
	    return rv;
	}
	catch (IntrospectionException e) { throw new Error(e.toString());}
    }
    
    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
	}

    public PropertyDescriptor[] getPropertyDescriptors() {
	try{
	    PropertyDescriptor frameWidth = 
		new PropertyDescriptor("frameWidth", BEAN_CLASS);
	    frameWidth.setBound(true);
	    frameWidth.setConstrained(false);
	    frameWidth.setDisplayName("frame width");
	    
	    PropertyDescriptor displayHi = 
		new PropertyDescriptor("displayHi", BEAN_CLASS);
	    displayHi.setBound(true);
	    displayHi.setConstrained(false);
	    displayHi.setDisplayName("display high");
	    
	    PropertyDescriptor displayLo = 
		new PropertyDescriptor("displayLo", BEAN_CLASS);
	    displayLo.setBound(true);
	    displayLo.setConstrained(false);
	    displayLo.setDisplayName("display low");
	    
	    PropertyDescriptor labelStyle = 
		new PropertyDescriptor("labelStyle", BEAN_CLASS);
	    labelStyle.setBound(true);
	    labelStyle.setConstrained(false);
	    labelStyle.setDisplayName("label style");
	    labelStyle.setValue("ENUMERATION", "LABEL_NONE=0, LABEL_AXIS=1, LABEL_VALUE=2, LABEL_ALL=3");
	    
	    PropertyDescriptor colorMode = 
		new PropertyDescriptor("colorMode", BEAN_CLASS);
	    colorMode.setBound(true);
	    colorMode.setConstrained(false);
	    colorMode.setDisplayName("color mode");
	    colorMode.setValue("ENUMERATION", "CLRMOD_STATIC=0, CLRMOD_ALARM=1, CLRMOD_DISCRETE=2");
	    
	    PropertyDescriptor rangeStyle = 
		new PropertyDescriptor("rangeStyle", BEAN_CLASS);
	    rangeStyle.setBound(true);
	    rangeStyle.setConstrained(false);
	    rangeStyle.setDisplayName("range style");
	    rangeStyle.setValue("ENUMERATION", "RANGE_FROM_PROPERTY=0, RANGE_AUTO=1, RANGE_STATIC=2");
	    
	    PropertyDescriptor[] rv = {frameWidth, displayHi, displayLo,
		                       labelStyle, colorMode, rangeStyle};
	    return rv;
	} catch (IntrospectionException e) { throw new Error(e.toString()); }
    }
        
}    // end of CAnimatedCanvasBeanInfo



