/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  06/22/00:  Release version 0.3.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CBits
 *
 * @version   0.3  06/22/00
 * @author    Ying Chen, Chip Watson
 * @since     adm0.3
 *
 */
public class CBitsBeanInfo extends SimpleBeanInfo {
    
    public BeanInfo[] getAdditionalBeanInfo() {
	try {
	    java.util.Vector v = new java.util.Vector();
	    BeanInfo[] rv;
	    BeanInfo b;
	    Class c = BEAN_CLASS.getSuperclass();
	    
	    while (c.isAssignableFrom(Object.class) != true) {
		b = Introspector.getBeanInfo(c);
		v.addElement(b);
		c = c.getSuperclass();
	    }
	    rv = new BeanInfo[v.size()];
	    v.copyInto(rv);
	    
	    return rv;
	}
	catch (IntrospectionException e) { throw new Error(e.toString());}
    }
    
    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
    }

    public java.awt.Image getIcon(int iconKind) {
	java.awt.Image img;
	if (iconKind == BeanInfo.ICON_MONO_16x16 ||
	    iconKind == BeanInfo.ICON_COLOR_16x16) {
	    img = loadImage("CBitsC16.gif");
	}	
	else if (iconKind == BeanInfo.ICON_MONO_32x32 ||
	    iconKind == BeanInfo.ICON_COLOR_32x32) {
	    img = loadImage("CBitsC32.gif");
	}
	else { img = null;   }
	return img;
    }

    public PropertyDescriptor[] getPropertyDescriptors() {
	try{
	    PropertyDescriptor dir = 
		new PropertyDescriptor("direction", BEAN_CLASS);
	    dir.setBound(true);
	    dir.setConstrained(false);
	    dir.setDisplayName("direction");
	    dir.setValue("ENUMERATION", "DIR_LEFT=0, DIR_RIGHT=1, DIR_UP=2, DIR_DOWN=3");
	    
	    PropertyDescriptor startBit = 
		new PropertyDescriptor("startBit", BEAN_CLASS);
	    startBit.setBound(true);
	    startBit.setConstrained(false);
	    startBit.setDisplayName("startBit");
	    
	    PropertyDescriptor endBit = 
		new PropertyDescriptor("endBit", BEAN_CLASS);
	    endBit.setBound(true);
	    endBit.setConstrained(false);
	    endBit.setDisplayName("endBit");
	    
	    PropertyDescriptor control = 
		new PropertyDescriptor("controllable", BEAN_CLASS);
	    control.setBound(true);
	    control.setConstrained(false);
	    control.setDisplayName("controllable");

	    PropertyDescriptor range = 
		new PropertyDescriptor("rangeStyle", BEAN_CLASS);
	    range.setHidden(true);
	    
	    PropertyDescriptor[] rv = {dir, startBit, endBit, control, range};
	    return rv;
	} catch (IntrospectionException e) { throw new Error(e.toString()); }
    }
    
    public int getDefaultPropertyIndex() {
	return 0;	//  the index for our default property is always 0
    }
    
    private final static Class BEAN_CLASS = CBits.class;
    
}	//  end of class CBitsBeanInfo
