/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  09/12/00:  Release version 0.4.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CPen
 *
 * @version   0.4  09/12/00
 * @author    Ying Chen, Chip Watson
 * @since     adm0.4
 *
 */
public class CPenBeanInfo extends SimpleBeanInfo {
    
    private final static Class BEAN_CLASS = CPen.class;
    
    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
    }

    public java.awt.Image getIcon(int iconKind) {
	java.awt.Image img;
	if (iconKind == BeanInfo.ICON_MONO_16x16 ||
	    iconKind == BeanInfo.ICON_COLOR_16x16) {
	    img = loadImage("CPenC16.gif");
	}	
	else if (iconKind == BeanInfo.ICON_MONO_32x32 ||
	    iconKind == BeanInfo.ICON_COLOR_32x32) {
	    img = loadImage("CPenC32.gif");
	}
	else { img = null; }
	return img;
	}
    
    public PropertyDescriptor[] getPropertyDescriptors() {
	try{
	    PropertyDescriptor deviceName = 
                new PropertyDescriptor("deviceName", BEAN_CLASS);
            deviceName.setBound(true);
            deviceName.setConstrained(false);
            deviceName.setDisplayName("device name");
            
            PropertyDescriptor propertyName = 
                new PropertyDescriptor("propertyName", BEAN_CLASS);
            propertyName.setBound(true);
            propertyName.setConstrained(false);
            propertyName.setDisplayName("property name");    

	    PropertyDescriptor high = 
		new PropertyDescriptor("displayHi", BEAN_CLASS);
	    high.setBound(true);
	    high.setConstrained(false);
	    high.setDisplayName("display high");
	    
	    PropertyDescriptor low = 
		new PropertyDescriptor("displayLo", BEAN_CLASS);
	    low.setBound(true);
	    low.setConstrained(false);
	    low.setDisplayName("display low");
	             
	    PropertyDescriptor color = 
		new PropertyDescriptor("penColor", BEAN_CLASS);
	    color.setBound(true);
	    color.setConstrained(false);
	    color.setDisplayName("pen color");

	    PropertyDescriptor[] rv = {deviceName, propertyName, high, low, color};
	    return rv;
	} catch (IntrospectionException e) { throw new Error(e.toString()); }
    }
    
    public int getDefaultPropertyIndex() {
	return 0;	//  the index for our default property is always 0
    }
    
}  // end of class CPenBeanInfo



