/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  09/12/00:  Release version 0.4.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CTrace
 *
 * @version   0.3  09/12/00
 * @author    Ying Chen, Chip Watson
 * @since     adm0.4
 *
 */
public class CTraceBeanInfo extends SimpleBeanInfo {
    
    private final static Class BEAN_CLASS = CTrace.class;
    
    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
    }

    public java.awt.Image getIcon(int iconKind) {
	java.awt.Image img;
	if (iconKind == BeanInfo.ICON_MONO_16x16 ||
	    iconKind == BeanInfo.ICON_COLOR_16x16) {
	    img = loadImage("CTraceC16.gif");
	}	
	else if (iconKind == BeanInfo.ICON_MONO_32x32 ||
	    iconKind == BeanInfo.ICON_COLOR_32x32) {
	    img = loadImage("CTraceC32.gif");
	}
	else { img = null; }
	return img;
	}
    
    public PropertyDescriptor[] getPropertyDescriptors() {
	try{
	    PropertyDescriptor xDeviceName = 
                new PropertyDescriptor("xDeviceName", BEAN_CLASS);
            xDeviceName.setBound(true);
            xDeviceName.setConstrained(false);
            xDeviceName.setDisplayName("x axis device name");
            
            PropertyDescriptor xPropertyName = 
                new PropertyDescriptor("xPropertyName", BEAN_CLASS);
            xPropertyName.setBound(true);
            xPropertyName.setConstrained(false);
            xPropertyName.setDisplayName("x axis property name");    

	    PropertyDescriptor xHigh = 
		new PropertyDescriptor("xDisplayHi", BEAN_CLASS);
	    xHigh.setBound(true);
	    xHigh.setConstrained(false);
	    xHigh.setDisplayName("x axis display high");
	    
	    PropertyDescriptor xLow = 
		new PropertyDescriptor("xDisplayLo", BEAN_CLASS);
	    xLow.setBound(true);
	    xLow.setConstrained(false);
	    xLow.setDisplayName("x axis display low");
	             
	    PropertyDescriptor xRange = 
                new PropertyDescriptor("xRangeStyle", BEAN_CLASS);
            xRange.setBound(true);
            xRange.setConstrained(false);
            xRange.setDisplayName("x axis range style");
            xRange.setValue("ENUMERATION", "RANGE_FROM_PROPERTY=0, RANGE_AUTO=1, RANGE_STATIC=2");
 
	    PropertyDescriptor yDeviceName = 
                new PropertyDescriptor("yDeviceName", BEAN_CLASS);
            yDeviceName.setBound(true);
            yDeviceName.setConstrained(false);
            yDeviceName.setDisplayName("y axis device name");
            
            PropertyDescriptor yPropertyName = 
                new PropertyDescriptor("yPropertyName", BEAN_CLASS);
            yPropertyName.setBound(true);
            yPropertyName.setConstrained(false);
            yPropertyName.setDisplayName("y axis property name");    

	    PropertyDescriptor yHigh = 
		new PropertyDescriptor("yDisplayHi", BEAN_CLASS);
	    yHigh.setBound(true);
	    yHigh.setConstrained(false);
	    yHigh.setDisplayName("y axis display high");
	    
	    PropertyDescriptor yLow = 
		new PropertyDescriptor("yDisplayLo", BEAN_CLASS);
	    yLow.setBound(true);
	    yLow.setConstrained(false);
	    yLow.setDisplayName("y axis display low");

	    PropertyDescriptor yRange = 
                new PropertyDescriptor("yRangeStyle", BEAN_CLASS);
            yRange.setBound(true);
            yRange.setConstrained(false);
            yRange.setDisplayName("y axis range style");
            yRange.setValue("ENUMERATION", "RANGE_FROM_PROPERTY=0, RANGE_AUTO=1, RANGE_STATIC=2");
	             
	    PropertyDescriptor style = 
		new PropertyDescriptor("traceStyle", BEAN_CLASS);
	    style.setBound(true);
	    style.setConstrained(false);
	    style.setDisplayName("trace style");
	    style.setValue("ENUMERATION", "STYLE_POINT=0, STYLE_LINE=1");
	    
	    PropertyDescriptor color = 
		new PropertyDescriptor("traceColor", BEAN_CLASS);
	    color.setBound(true);
	    color.setConstrained(false);
	    color.setDisplayName("trace color");
	    PropertyDescriptor[] rv = {xDeviceName, xPropertyName, xHigh, xLow, xRange, yDeviceName, yPropertyName, yHigh, yLow, yRange, style, color};
	    return rv;
	} catch (IntrospectionException e) { throw new Error(e.toString()); }
    }
    
    public int getDefaultPropertyIndex() {
	return 0;	//  the index for our default property is always 0
    }
    
}  // end of class CTrace



