/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  10/07/00:  Release version 1.0.
 *
 */

package adm;

import java.beans.*;

/**
 * BeanInfo for CWheelSwitch widget
 *
 * @version   1.0  09/12/00
 * @author    Ying Chen, Chip Watson
 * @since     adm1.0
 *
 */

public class CWheelSwitchBeanInfo extends SimpleBeanInfo {

    private final static Class BEAN_CLASS = CWheelSwitch.class;

    public BeanDescriptor getBeanDescriptor() {
	BeanDescriptor bd = new BeanDescriptor(BEAN_CLASS);
	return (BeanDescriptor) bd;
    }

    public java.awt.Image getIcon(int iconKind) {
	java.awt.Image img;
	if (iconKind == BeanInfo.ICON_MONO_16x16 ||
	    iconKind == BeanInfo.ICON_COLOR_16x16) {
	    img = loadImage("CWheelSwitchC16.gif");
	}
	else if (iconKind == BeanInfo.ICON_MONO_32x32 ||
	    iconKind == BeanInfo.ICON_COLOR_32x32) {
	    img = loadImage("CWheelSwitchC32.gif");
	}
	else { img = null; }
	return img;
    }
    
    public PropertyDescriptor[] getPropertyDescriptors() {
        try {
	    PropertyDescriptor deviceName = 
                new PropertyDescriptor("deviceName", BEAN_CLASS);
            deviceName.setBound(true);
            deviceName.setConstrained(false);
            deviceName.setDisplayName("device name");
            
            PropertyDescriptor propertyName = 
                new PropertyDescriptor("propertyName", BEAN_CLASS);
            propertyName.setBound(true);
            propertyName.setConstrained(false);
            propertyName.setDisplayName("property name");
            
	     PropertyDescriptor colorMode = 
                new PropertyDescriptor("colorMode", BEAN_CLASS);
            colorMode.setBound(true);
            colorMode.setConstrained(false);
            colorMode.setDisplayName("color mode");
            colorMode.setValue("ENUMERATION", "CLRMOD_STATIC=0, CLRMOD_ALARM=1, CLRMOD_DISCRETE=2");

            PropertyDescriptor[] rv = {deviceName, propertyName, colorMode};
            return rv;
        } catch (IntrospectionException e) { throw new Error(e.toString()); }
    }


}  // end of CWheelSwitchBeanInfo
