/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 * Revision History:
 *   08/07/00  Release version 0.4 (Initial version).
 *
 */

package adm.event;

import java.util.*;

/**
 * CTrace event generated by CTrace object
 *
 * @version   0.4  09/17/00
 * @author    Ying Chen, Chip Watson
 *            
 * @since     adm0.4
 */
public class CTraceEvent extends EventObject {

    private double[] xValue;
    private double[] yValue;

    /**
     * Constructor 
     * 
     * @param source    event source
     * @param val       value set pair
     */
    public CTraceEvent (Object source, double[] x, double[] y) {
	super (source);
	xValue = x;
	yValue = y;
    }

    public int getDataLength() {
	return xValue.length;
    }

    /** 
     * Return x data array
     */
    public double[] getXValue () {
	return xValue;
    }

    /** 
     * Return y data array
     */
    public double[] getYValue () {
	return yValue;
    }

    /** 
     * Return data set pair as Double[] at position i
     */
    public Double[] getDoubleValue (int i) {
	Double[] value = new Double[2];
	value[0] = new Double(xValue[i]);
	value[1] = new Double(yValue[i]);
	return value;
    }
}
