// $Id: Config.java,v 1.10 2000/04/20 16:46:40 watson Exp $
// (c) Copyright ...
//----------------------------------------------------------------------------
// Revision History:
//  3-Sep-98  FDM integrate a PS JNI service into CDEV 20 prototype.
//  3-Jun-99  CW changed to use dynamic class loading

/**
 * The Config class define the connection between CDEV generic classes
 * and the local implementation.
 * This class has only static methods.
 * @author Franck Di Maio
 * @version $Revision: 1.10 $
 * @since JDK1.1
 */

package cdev;

import cdev.io.*;
import cdev.dir.*;

import java.lang.reflect.*;
import java.util.Properties; // to choose IOService with an environment variable

public class Config {

  private static String DEFAULT_IOSERVICE = "cdev.clip.ClipService";
  // static String DEFAULT_IOSERVICE = "cdev.io.psjni.PSIOService";

  private static String DEFAULT_DIRSERVICE = "cdev.dir.gateway.GatewayDirService";
  // static String DEFAULT_DIRSERVICE = "cdev.dir.service.DirServiceImplementation";

  private static IOService ioservice;
  private static DirectoryService dirservice;

  /** Returns the IOService that implements transactions with a Device. */
  public static IOService getIOService (Device device) 
    throws ClassNotFoundException, InstantiationException, IllegalAccessException 
  {
    if (ioservice==null) {
      String choice = null;
      try { // may get a security exception in browser
	Properties props = System.getProperties();
	choice = props.getProperty("cdev.io.defaultService",DEFAULT_IOSERVICE);
      } catch (Exception e) {choice = DEFAULT_IOSERVICE;}
      Class c = Class.forName(choice);
      try {
	Method factory = c.getMethod("getIOService",null);
	Object obj = factory.invoke(null,null);
	System.out.println("factory service object:"+obj);
	ioservice = (IOService) obj;
      } catch (Exception e) {
	throw new InstantiationException(e.toString());
      }
    }
    return ioservice;
  }

  /** Returns the directory service.
   */
  public static DirectoryService getDirectoryService()
       throws ClassNotFoundException, InstantiationException, IllegalAccessException {

    String choice = null;
    try { // may get a security exception in browser
      Properties props = System.getProperties();
      choice = props.getProperty("cdev.io.defaultService",DEFAULT_DIRSERVICE);
    } catch (Exception e) {choice = DEFAULT_DIRSERVICE;}
    Class c = Class.forName(choice);

    try {
	Method factory = c.getMethod("getService",null);
	dirservice = (DirectoryService) factory.invoke(null,null);
    } catch (Exception e) {
	throw new InstantiationException(e.toString());
    }
    return dirservice;
  }

}

