//-----------------------------------------------------------------------------
//
//  Description:
//      Error class for cdev
//
//  Author: Chip Watson
//
//-----------------------------------------------------------------------------
// Revision History:
//
// 11-Aug-98  CW Prototype version
//  3-Sep-98  FDM Add attributes, make all attributes protected, 
//            modify toString, add constructor.
// 27-Nov-98  FDM add context
//
//-----------------------------------------------------------------------------

package cdev;

import cdev.data.Data;

public class DeviceError extends Exception {

  protected DeviceEvent event;
  protected int code;
  protected String message;
  protected String name;
  protected String category;
  protected Data context;	// I/O context: timeStamp, cycleStamp, etc.

  public DeviceError (DeviceEvent event, int code, String message)
    {
	super ("DeviceError: " + event + message);
	this.event = event;
	this.code = code;
	this.message = message;
	name = "Err#" + code;	// default
	category = "I/O";	// default
    }

  public DeviceEvent getEvent() {return event;}

  public int getCode() { return code;}

  public String getMessage () { return message;}

  public String getCategory() { return category;}

  public String getName() { return name;}

  public Data getContext() { return context; }

  // modified. FDM
  public String toString() {
    return (category + " error " + name + ": " 
	    + event + ", " + message); // to be reviewed. FDM
  }
}

  

