//-----------------------------------------------------------------------------
//
//  Description:
//      CLIP Echo Server.  This server accepts a connection, and
//      echos all messages sent to it. 
//      Buffers are received fully, then returned with no
//      interpretation. 2nd longword is buffer length to follow.
//
//  Author: Chip Watson
//
//  This class extends Thread to continuously read the socket.
//
//-----------------------------------------------------------------------------
// Revision History:
//
//  9-Oct-98  CW Prototype version
//
//-----------------------------------------------------------------------------

package cdev.clip;

import cdev.*;
import cdev.data.*;
import java.io.*;
import java.net.*;
import java.util.*;

public class ClipEchoServer extends Thread {

  public static void main (String [] argv) {

    int port = Integer.parseInt(argv[0]);
    int maxdump = 0;

    if (argv.length > 1) {
      maxdump = Integer.parseInt(argv[1]);
    }

    byte [] buffer = new byte[20000];

    try {
      ServerSocket server = new ServerSocket(port);

      System.out.println("Server socket created: "+server);
      while (true) {

	try {

	  Socket client = server.accept();
	  System.out.println("received a connection from "+client);

	  InputStream in = client.getInputStream();
	  OutputStream out = client.getOutputStream();

	  while (true) {

	    int count = in.read(buffer,0,8);
	    while (count < 8) {
	      int next = in.read(buffer,count,8-count);
	      if (next < 0) throw (new Exception("bad partial read of length"));
	      count += next;
	    }
	    int buflen = buffer[4];
	    for (int i=5;i<8;i++) {
		buflen <<=8;
		int temp = buffer[i];
		temp &= 255;
		buflen += temp;
	    }
	    if (buflen < 0)
	      break;

	    buflen += 8; // for clip buffer header itself, magic + length
	    if (maxdump>0) System.out.println(" buflen "+buflen);

	    int offset = 8;
	    int left = buflen - offset;
	    while (left > 0) {
	      int next = in.read(buffer,offset,left);
	      if (next < 0) throw (new Exception("bad partial read of length"));
	      offset += next;
	      left -= next;
	    }

	    out.write(buffer,0,offset);
	    //System.out.println("xfer " + offset);

	    if (buflen > maxdump) buflen = maxdump;
	    for (int i=0; i<buflen/4; i++) {
	      System.out.print(" "+buffer[4*i]);
	      System.out.print(" "+buffer[4*i + 1]);
	      System.out.print(" "+buffer[4*i + 2]);
	      System.out.println(" "+buffer[4*i + 3]);
	    }
	    for (int j=4*(buflen/4); j<buflen; j++)
	      System.out.print(" "+buffer[j]);
	    if (buflen > 0)
	      System.out.println(" ");
	  }

	} catch (Exception e) {}

      }

    } catch (Exception e) {}

  }

}
