//-----------------------------------------------------------------------------
//
//  Description:
//      Transaction class for clip
//
//  Author: Chip Watson
//
//-----------------------------------------------------------------------------
// Revision History:
//
// 27-Apr-99  CW  Initial version
//  3-Feb-00  CW  Bug fix in getDeviceName
//
//-----------------------------------------------------------------------------

package cdev.clip;

import cdev.*;
import cdev.data.*;

import java.util.*;
import java.io.*;

public class ClipTransaction extends DeviceTransaction {

  int clientID;
  int clienttrans;
  private String [] devnames;
  private Data context;

  ClipTransaction(int cid, int ctrans, String [] dnames, 
		  int opcode, String arg, Data data, Data ctx,
		  TransactionResponseListener lis) {
    this.opcode = opcode;
    this.arg = arg;
    outbound = data;
    context = ctx;
    this.listener = lis;
    devnames = dnames;
    clientID = cid;
    clienttrans = ctrans;
  }

  /**
   * Constructor used by "cancel" operation
   */
  ClipTransaction(Device d, int op, String arg) {
    super(d,op,arg,(Data)null,(DeviceListener)null);
  }

  public String getDeviceName() {return (devnames==null)?null:devnames[0];}

  public String [] getDeviceNames() {return devnames;}

  public Data getContextData() {return context;}

  void setState(int state) {this.state = state;}

  // defer Device creation s.t. if not needed, not used
  public Device getDevice() {
    if (device == null) try {
      if (devnames.length==1)
        device = new Device(devnames[0]);
      else
	device = new DeviceArray("unknown",devnames);
      if (context != null) device.setContext(context);
    } catch (Exception e) {
      System.out.println("clip getDevice failure for "+devnames.length+" "+devnames[0]);
    }
    return device;
  }
}

