//-----------------------------------------------------------------------------
// Copyright (c) 1994,1995 Southeastern Universities Research Association,
//                         Continuous Electron Beam Accelerator Facility
//
// This software was developed under a United States Government license
// described in the NOTICE file included as part of this distribution.
//
//-----------------------------------------------------------------------------
//
// Description:
//      Java Implementation of cdevGlobalTagTable and cdevTagTable
//
//      cdevTagTable class manages tags within the cdev system; java
//      implementation uses only TagTable to reduce class count
//
// Author:  Chip Watson
//
// From work by Jie Chen, Danjin Wu, Walt Akers
//
//---------------------------------------------------------------------------
// Revision History:
//
// 9-22-96: Add static definitions for data types for use with xdrImport
//          and xdrExport in Data class.
//
// 3-26-97: Add 3 additional tags to tag table. (collection, resultCode, clientID)
// 5-15-98: Add non-existant key detection in convertKey(String). FDM.
// 3-Sep-98: Add 2 tags (cycleType, timingEvent). FDM 
// 13-Nov-98: Add tag cycleStamp. FDM
// 3-Dec-98: Add tag referenceKey M.C
// 22-Apr-99: Add tag onChange for monitor filter M.C
// 27-Apr-99: Add tag timeOut (use in DeviceContext for IO methods). M.C
// 
//---------------------------------------------------------------------------

package cdev.data;

import java.lang.*;
import java.util.*;

class TagTable {

  static boolean initialized;
  static TagTable tagTable = new TagTable();
  static Hashtable ikey;
  static Hashtable skey;

  public TagTable () {
    int HASHTABLESIZE = 137;
    float HASHLOAD = (float) 0.25;
    try {
        ikey = new Hashtable(HASHTABLESIZE,HASHLOAD);
        skey = new Hashtable(HASHTABLESIZE,HASHLOAD);
    } catch (IllegalArgumentException e) {
    }
    initialize ();
  }

  static void initialize () {
    if (initialized) return;
    int MAXSTRINGS = 30;	// Source inepuisable d'emmerdements. FDM
    String strings[] = new String[MAXSTRINGS];
    int i = 0;
  
    strings[i++]  = "value";
    strings[i++]  = "status";  
    strings[i++]  = "severity";
    strings[i++]  = "time";
    strings[i++]  = "units";
    strings[i++]  = "displayHigh";
    strings[i++]  = "displayLow";
    strings[i++]  = "alarmHigh";
    strings[i++]  = "alarmLow";
    strings[i++]  = "warningHigh";
    strings[i++]  = "warningLow";
    strings[i++]  = "controlHigh";
    strings[i++]  = "controlLow";
    strings[i++]  = "bitMask";
    strings[i++]  = "file";
    strings[i++]  = "class";
    strings[i++]  = "device";
    strings[i++]  = "message";
    strings[i++]  = "verb";
    strings[i++]  = "attribute";
    strings[i++]  = "collection";
    strings[i++]  = "resultCode"; // the completion code of a server operation
    strings[i++]  = "clientID";	  // Used in context to identify a client
    strings[i++]  = "precision";  // added in 2.2.2
    // CERN additions
    strings[i++]  = "cycleType"; // Timing system parameter
    strings[i++]  = "timingEvent";
    strings[i++]  = "cycleStamp";
    strings[i++]  = "referenceKey";
    strings[i++]  = "timeOut";
    strings[i++]  = "onChange";

    try {
      for(i=1; i<=MAXSTRINGS; i++) {
        insert(i, strings[i-1]);
      }
    } catch (IllegalArgumentException e) {
    }
    initialized = true;
  }

  public static void main(String argv[]) {
    int MAXSTRINGS = 29;

    for(int i=1; i<=MAXSTRINGS; i++){
        String s = convertKey(i);
        System.out.println("Tag " + i + " " + s);
        int  a = convertKey(s);
        System.out.println ("--->" + a);
    }
  }


  public static int convertKey(String key) {
    Integer itag = (Integer) skey.get(key);
    if (itag == null)
	return 0;
    return itag.intValue();
  }

  public static String convertKey(int key) {
    Integer itag = new Integer(key);
    return (String) ikey.get(itag);
  }

  public static void insert(int tag, String ctag)
    throws IllegalArgumentException {

    Integer itag = new Integer(tag);

    if (ikey.containsKey(itag)) throw new IllegalArgumentException
      ("duplicate integer " + itag.toString());
    if (skey.containsKey(ctag)) throw new IllegalArgumentException
      ("duplicate tag name " + ctag);

    ikey.put(itag,ctag);
    skey.put(ctag,itag);

  }

}

